%% Template class for AAG2018 by Alexander Sehlström, alexander.sehlstrom@chalmers.se
%% 2018-04-04

\NeedsTeXFormat{LaTeX2e}

\ProvidesClass{aag2018}[2018-04-04 AAG2018 paper class]

% Macro for checking all required commands are set.
\newcommand{\@checkifdefined}[1]{%
  \@ifundefined{@#1}{\ClassError{aag2018}{User input `#1` undefined.}{Use the \textbackslash #1{} command to set it.}}{}%
}

%% Options of class
\DeclareOption{10pt}{\OptionNotUsed}
\DeclareOption{12pt}{\OptionNotUsed}
\DeclareOption{twocolumn}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[11pt,b5paper,twoside]{article}

% Set up with the required packages
\RequirePackage{etoolbox}

\RequirePackage{lastpage} % To be able to reference to last page number

\RequirePackage[tmargin=22.5mm, headheight=5mm, bottom=15mm, footskip=7.5mm, left=22.5mm, right=22.5mm]{geometry}

% Adjustments of floats and equations.
\setlength{\intextsep}{12pt}
\setlength{\abovedisplayskip}{6pt}
\setlength{\belowdisplayskip}{6pt}
\setlength{\parindent}{5mm}
\setlength{\abovecaptionskip}{6pt}
\setlength{\belowcaptionskip}{6pt} % Actual skip = \textfloatsep + \belowcaptionskip
\setlength{\itemsep}{0pt}

%  setup for user loaded packages.
\AtEndPreamble{
    % Check for amsmath
    \@ifpackageloaded{amsmath}{
    }{\ClassWarning{aag2018}{Package 'amsmath' strongly recommended.}}
    
    % Figure captions
    \@ifpackageloaded{subfig}{
        \captionsetup[subfigure]{textfont=it}
    }{\ClassWarning{aag2018}{Package 'subfig' strongly recommended}}

    \@ifpackageloaded{caption}{
        \captionsetup[figure]{textfont=it}
    }{\ClassWarning{aag2018}{Package 'caption' required}}
    
    % Document metadata setup
    \@ifpackageloaded{hyperref}{
        \@checkifdefined{title}
        \@checkifdefined{author}
        \@checkifdefined{keywords}
        \renewcommand{\and}{, }
        \hypersetup{
            breaklinks,
            pdfcreator    = \LaTeX{},
            pdfproducer   = \LaTeX{},
            bookmarksopen = true,
            pdfauthor     = \@authorNames,
            pdftitle      = \@title,
            pdfkeywords   = \@keywords,
            colorlinks = true,
            urlcolor   = black,
            citecolor  = black,
            linkcolor  = black,
            filecolor  = black,
        }
    }{\ClassWarning{aag2018}{Package 'hyperref' required}}
}

% User preamble commands
\def\author{\@ifnextchar[{\@getshortauthor}{\@getauthor}}
\def\@getauthor#1{\gdef\@author{#1}\gdef\@shortauthor{#1}}
\def\@getshortauthor[#1]#2{\gdef\@shortauthor{#1}\gdef\@author{#2}}
\newcommand{\authorNames}[1]{\gdef\@authorNames{#1}}
\renewcommand{\title}[1]{\gdef\@title{#1}}
\newcommand{\subtitle}[1]{\gdef\@subtitle{#1}} % Optional
\newcommand{\address}[1]{\gdef\@address{#1}}
\newcommand{\keywords}[1]{\gdef\@keywords{#1}}
\renewcommand{\abstract}[1]{\gdef\@abstract{#1}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Städad hit.
\RequirePackage{calc}

\RequirePackage{mathptmx}

\RequirePackage{caption} % To fix size and distances for captions.
\DeclareCaptionFont{xipt}{\fontsize{11}{13}\mdseries}
\RequirePackage[font=xipt]{caption}

\RequirePackage[T1]{fontenc}
\renewcommand*\familydefault{\sfdefault} %% Only if the base font of the document is to be sans serif

\RequirePackage{natbib} % Turns normal citation into the required format. See natbib for references on cite commands, e.g. \citep \citet etc.

\pagenumbering{arabic}

%% Title command
\renewcommand{\maketitle}{%
	\newpage%
	\thispagestyle{AAGfirstheadings}%
	\vspace*{48pt}%
	{%2 Title
		\fontsize{16}{19.2}\selectfont%
		\bfseries%
		\@title%
		\par%
	}%2
	{%3 Subtitle
	    \fontsize{14}{16.8}\selectfont%
	    \@ifundefined{@subtitle}{}{{\@subtitle\par}}
	}%3
	\vspace{12pt}%
	{%4
		\fontsize{11}{13.2}\selectfont%
        \@author%
		\par%
	}%4
	\vspace{3pt}%
	{%5
		\fontsize{10}{12}\selectfont%
		\@address%
		\par%
	}%5
	\vspace{24pt}%
	{%6 
	\renewcommand{\section}{%
		\@startsection{section}{1}{\z@}%
		{-0pt}%
		{3pt}%
		{\fontsize{12}{14.4}\selectfont\bfseries}%
	}%
	\section*{Abstract}%
	\fontsize{11}{12}\selectfont%
	\noindent\@abstract%
	\par%
	}%6
	\vspace{4pt}%
	{%7
		\fontsize{9}{10.8}\selectfont%
		\noindent\textbf{Key words:\space}\@keywords%
		\par%
	}%7
	\pagebreak%
}% End of \@maketitle

%% Headings for first page
\def\ps@AAGfirstheadings{%
	\def\@oddfoot{}%
	\let\@evenfoot\@oddfoot
	\def\@evenhead{%
        \begin{minipage}[b][20mm][t]{0.5\textwidth} 
            \includegraphics[width=24mm]{AAG2018_logo.png}
            \vspace{6pt}\\
            {\fontsize{8}{9.6}\selectfont \textbf{Advances in Architectural Geometry 2018} \\
            Chalmers University of Technology \\
            Gothenburg, Sweden \\
            22-25 September 2018
            
            www.architecturalgeometry.org/aag18}
		\end{minipage}
	}%
	\let\@oddhead\@evenhead
	\let\@mkboth\@gobbletwo
	\let\sectionmark\@gobble
	\let\subsectionmark\@gobble
}

%% Headings for consecutive pages
\def\ps@AAGheadings{%
	\def\@oddfoot{}%
    \let\@evenfoot\@oddfoot
    \def\@evenhead{%
        \begin{minipage}[b][20mm][t]{\textwidth}
            \begin{flushright}
                {\fontsize{8}{9.6}\selectfont \@authorNames \par}
            \end{flushright}
		\end{minipage}
	}%
	\def\@oddhead{%
        \begin{minipage}[b][20mm][t]{\textwidth}
            {\fontsize{8}{9.6}\selectfont \@title }
		\end{minipage}
    }%
	\let\@mkboth\@gobbletwo
	\let\sectionmark\@gobble
	\let\subsectionmark\@gobble
}

%% Fix sections and paragraph skip
\RequirePackage{parskip}
\setlength{\parskip}{0.5\baselineskip} % Change parskip's default, is reset after the sections are defined.

% Section level 1
\renewcommand{\section}{%
  \@startsection{section}{1}{\z@}%
  {-13pt \@plus -13pt \@minus -13pt}%
  {3pt}%
  {\fontsize{13}{15.6}\selectfont\bfseries}%
}

% Section level 2
\renewcommand{\subsection}{%
  \@startsection{subsection}{2}{\z@}%
  {-11pt \@plus -11pt \@minus -11pt}%
  {3pt}%
  {\fontsize{11}{13.2}\selectfont\bfseries}%
}

% Section level 3
\renewcommand{\subsubsection}{%
  \@startsection{subsubsection}{3}{\z@}%
  {-11pt \@plus -11pt \@minus -11pt}%
  {3pt}%
  {\fontsize{11}{13.2}\selectfont\itshape}%
}

% Caption command
\renewcommand{\@makecaption}[2]{%
	\vskip\abovecaptionskip
	\sbox\@tempboxa{{\fontsize{10}{12}\selectfont\itshape #1: #2}}%
	\ifdim \wd\@tempboxa >\hsize
		{\fontsize{10}{12}\selectfont\itshape #1: #2\par}
	\else
		\global \@minipagefalse
		\hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
	\fi
	\vskip\belowcaptionskip
}

\AtBeginDocument{%
  \pagestyle{AAGheadings}
}

\endinput